.. _index:

.. pysaml2 documentation master file, created by
   sphinx-quickstart on Mon Aug 24 08:13:41 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation of pysaml2!
========================================

:Release: |release|
:Date: |today|

Contents:

.. toctree::
   :maxdepth: 1

   install
   howto/index
   saml2
   examples/index
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

